{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": "FragGeneScan",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "train/model",
                            "entry": "$(inputs.model.main)"
                        },
                        {
                            "entryname": "train/gene",
                            "entry": "$(inputs.model.prob_forward)"
                        },
                        {
                            "entryname": "train/rgene",
                            "entry": "$(inputs.model.prob_backward)"
                        },
                        {
                            "entryname": "train/noncoding",
                            "entry": "$(inputs.model.prob_noncoding)"
                        },
                        {
                            "entryname": "train/start",
                            "entry": "$(inputs.model.prob_start)"
                        },
                        {
                            "entryname": "train/stop",
                            "entry": "$(inputs.model.prob_stop)"
                        },
                        {
                            "entryname": "train/start1",
                            "entry": "$(inputs.model.prob_start1)"
                        },
                        {
                            "entryname": "train/stop1",
                            "entry": "$(inputs.model.prob_stop1)"
                        },
                        {
                            "entryname": "train/pwm",
                            "entry": "$(inputs.model.pwm_dist)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/predicted_cds"
                },
                {
                    "prefix": "-t",
                    "valueFrom": "model"
                }
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.ffn"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_nuc"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                }
            ],
            "baseCommand": "cat",
            "stdout": "result",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    },
                    "id": "#concatenate.cwl/result"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\ncurrentSequences = []\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + \\\\\n                       currentSequences[-1].id + \".fasta\"\n        for char in [ \"/\", \" \", \":\" ]:\n            fileName = fileName.replace(char, \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + \\\\\n                   currentSequences[-1].id + \".fasta\"\n    for char in [ \"/\", \" \", \":\" ]:\n        fileName = fileName.replace(char, \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Find reads with predicted coding sequences above 60 AA in length",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#main/combine_predicted_CDS_aa/result",
                    "id": "#main/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#main/combine_predicted_CDS_nuc/result",
                    "id": "#main/predicted_CDS_nuc"
                }
            ],
            "steps": [
                {
                    "doc": "Find reads with predicted coding sequences (pCDS)\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "source": "#main/completeSeq",
                            "id": "#main/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#main/model",
                            "id": "#main/ORF_prediction/model"
                        },
                        {
                            "source": "#main/split_seqs/chunks",
                            "id": "#main/ORF_prediction/sequence"
                        }
                    ],
                    "scatter": "#main/ORF_prediction/sequence",
                    "out": [
                        "#main/ORF_prediction/predicted_CDS_aa",
                        "#main/ORF_prediction/predicted_CDS_nuc"
                    ],
                    "id": "#main/ORF_prediction"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/ORF_prediction/predicted_CDS_aa",
                            "id": "#main/combine_predicted_CDS_aa/files"
                        }
                    ],
                    "out": [
                        "#main/combine_predicted_CDS_aa/result"
                    ],
                    "id": "#main/combine_predicted_CDS_aa"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/ORF_prediction/predicted_CDS_nuc",
                            "id": "#main/combine_predicted_CDS_nuc/files"
                        }
                    ],
                    "out": [
                        "#main/combine_predicted_CDS_nuc/result"
                    ],
                    "id": "#main/combine_predicted_CDS_nuc"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 100000,
                            "id": "#main/split_seqs/chunk_size"
                        },
                        {
                            "source": "#main/sequence",
                            "id": "#main/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#main/split_seqs/chunks"
                    ],
                    "id": "#main/split_seqs"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
